==> vue-hooks-plus-1.3.1.tgz: package/README.md <==
<p align="center">
  <a href="http://43.138.187.142:9000/vue-hooks-plus/docs/">
    <img width="216" src="http://43.138.187.142:9000/assets/vue-hooks-plus/logo@2x.png">
  </a>
</p>

<div align="center">

[ahooks](https://ahooks.js.org/) Vue realize.

<h1 style="background: -webkit-linear-gradient(315deg, #42d392 25%, #647eff); background-clip: text;
-webkit-background-clip: text;-webkit-text-fill-color: transparent;">Vue-hooks-plus</h1>

English | [简体中文](https://github.com/InhiblabCore/vue-hooks-plus/tree/master/README.zh-CN.md)

</div>

## 📚 Documentation

[Docs Live](http://43.138.187.142:9000/vue-hooks-plus/docs/)

## ✨ Features

- Easy to learn and use
- Supports SSR
- Contains a comprehensive collection of basic Hooks
- A wide range of application scenarios
- Written in TypeScript with predictable static types
- Support the on-demand load, and reduce the packing volume

## 📦 Install

```
$ npm install --save vue-hooks-plus
# or
$ yarn add vue-hooks-plus
```

## 🔨  Usage

```typescript
import { useRequest } from 'vue-hooks-plus'

// or Introduced on demand

import useRequest from 'vue-hooks-plus/es/useRequest'
```

## 🏃 Start the document

hooks Dir

```
npm run initial
npm run docs:dev
```

Note: You need to initialize before starting the document project. Due to the plug-ins, `useAsyncOrder`, `useBoolean` and `useCookieState` initialization will be open, so you need to manually go to the md file in the current folder to save it. The plug-in will listen for the save operation and will be repaired later.

==> vue-hooks-plus-1.3.4.tgz: package/README.md <==
<p align="center">
  <a href="http://43.138.187.142:9000/vue-hooks-plus/docs/">
    <img width="216" src="http://43.138.187.142:9000/assets/vue-hooks-plus/logo@2x.png">
  </a>
</p>

<div align="center">

[ahooks](https://ahooks.js.org/) Vue realize.

<h1 style="background: -webkit-linear-gradient(315deg, #42d392 25%, #647eff); background-clip: text;
-webkit-background-clip: text;-webkit-text-fill-color: transparent;">VueHooks Plus</h1>

English | [简体中文](https://github.com/InhiblabCore/vue-hooks-plus/tree/master/README.zh-CN.md)

</div>

## 📚 Documentation

[Docs Live](http://43.138.187.142:9000/vue-hooks-plus/docs/)

## ✨ Features

- Easy to learn and use
- Supports SSR
- Contains a comprehensive collection of basic Hooks
- A wide range of application scenarios
- Written in TypeScript with predictable static types
- Support the on-demand load, and reduce the packing volume

## 📦 Install

```
$ npm install --save vue-hooks-plus
# or
$ yarn add vue-hooks-plus
```

## 🔨  Usage

```typescript
import { useRequest } from 'vue-hooks-plus'

// or Introduced on demand

import useRequest from 'vue-hooks-plus/es/useRequest'
```

## 🏃 Start the document

hooks Dir

```
npm run initial
npm run docs:dev
```

Note: You need to initialize before starting the document project. Due to the plug-ins, `useAsyncOrder`, `useBoolean` and `useCookieState` initialization will be open, so you need to manually go to the md file in the current folder to save it. The plug-in will listen for the save operation and will be repaired later.
